@@ -3,12 +3,25 @@ from types import MethodType
 from typing import Dict, Optional
 from urllib.parse import urljoin
 
+import authlib.integrations.httpx_client.oauth2_client
+import httpx
 from authlib.integrations.httpx_client import AsyncOAuth2Client
 from httpx import ConnectError, ConnectTimeout, HTTPError, HTTPStatusError, Response
 
 from .exceptions import InvalidCommandException, LitterRobotException
 from .litterrobot import LitterRobot, Vendor
 
+# httpx==0.18.2 switched to an object called `USE_CLIENT_DEFAULT` instead of `UNSET`
+# The latest release of Authlib (0.15.4 as of this writing) has not included this fix
+# though it does exist in the master branch of Authlib. Because of this, we need to
+# check the version and patch the issue if httpx is on or after version 0.18.2
+if httpx.__version__ >= "0.18.2" and not hasattr(
+    authlib.integrations.httpx_client.oauth2_client, "USE_CLIENT_DEFAULT"
+):
+    from httpx import USE_CLIENT_DEFAULT
+
+    authlib.integrations.httpx_client.oauth2_client.UNSET = USE_CLIENT_DEFAULT
+
 
 class Session:
     def __init__(self, vendor: Vendor):
@@ -35,7 +48,7 @@ class Session:
     def generate_headers(
         self, custom_headers: Optional[Dict[str, str]] = None
     ) -> Dict[str, str]:
-        """"Merge self.headers with custom headers if necessary."""
+        """Merge self.headers with custom headers if necessary."""
         if not custom_headers:
             return self.headers
 
@@ -70,8 +83,7 @@ class OAuth2Session(Session):
 
     async def fetch_token(self, username: str, password: str) -> Dict[str, str]:
         """Fetch an access token via oauth2."""
-        async with self._client:
-            await self._client.fetch_token(username=username, password=password)
+        return await self._client.fetch_token(username=username, password=password)
 
     async def get(self, path: str, **kwargs) -> Response:
         """Make a get request."""
@@ -90,10 +102,9 @@ class OAuth2Session(Session):
         url = self.urljoin(path)
         headers = self.generate_headers(kwargs.pop("headers", None))
         try:
-            async with self._client:
-                response = await method(url, headers=headers, **kwargs)
-                response.raise_for_status()
-                return response
+            response = await method(url, headers=headers, **kwargs)
+            response.raise_for_status()
+            return response
         except (HTTPStatusError, HTTPError, ConnectTimeout, ConnectError) as ex:
             if isinstance(ex, HTTPStatusError) and ex.response.status_code == 500:
                 raise InvalidCommandException(
